@@ -62,7 +62,7 @@ class Validator():
 		- Validator.validate_url("https://example.com/") -> True
 		- Validator.validate_url("example.com") -> False'''
 		# https://urlregex.com/
-		return cls.is_re_pattern_in_text(r"http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+", url)
+		return cls.is_re_pattern_in_text(r"^http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+$", url)
 
 	@staticmethod
 	def validate_ipv4(ip: str) -> bool:
