@@ -22,7 +22,7 @@
 import re
 def test_stringtools_version_name():
 	'''Checks if package version name follows semantic versioning'''
-	from stringtools import Validator
+	from stringtools.validators import Validator
 	with open("setup.cfg", "r") as _file:
 		data = _file.read()
 	assert Validator.validate_semver(re.findall(r"\nversion(?:[\s]+|[\s])?[=](?:[\s]+|[\s])?(.*)", data)[0]) == True
\ No newline at end of file
